@@ -475,7 +475,7 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-#define HAVE_ERR_remove_thread_state 1
+/* #undef HAVE_ERR_remove_thread_state */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -492,7 +492,6 @@
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
 /* #undef _LARGEFILE64_SOURCE */
-#define _FILE_OFFSET_BITS 64
 
 #define TIME_WITH_SYS_TIME 1
 
@@ -602,8 +601,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-#define HAVE_EncryptAes128Ctr 1
-#define HAVE_EncryptAes128Gcm 1
+/* #undef HAVE_EncryptAes128Ctr */
+/* #undef HAVE_EncryptAes128Gcm */
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -641,16 +640,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 21
+#define MYSQL_VERSION_PATCH 23
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.21"
+#define PACKAGE_STRING "MySQL Server 10.1.23"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.21"
-#define VERSION "10.1.21"
+#define PACKAGE_VERSION "10.1.23"
+#define VERSION "10.1.23"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
